@@ -33,7 +33,7 @@ use crate::{CBOR_TAGS_CID, CBOR_TAGS_MAJOR_TYPE_AND_CID};
 /// Deserialize a `String`
 ///
 /// ```
-/// # use serde_cbor::de;
+/// # use serde_ipld_dagcbor::de;
 /// let v: Vec<u8> = vec![0x66, 0x66, 0x6f, 0x6f, 0x62, 0x61, 0x72];
 /// let value: String = de::from_slice(&v[..]).unwrap();
 /// assert_eq!(value, "foobar");
@@ -42,7 +42,7 @@ use crate::{CBOR_TAGS_CID, CBOR_TAGS_MAJOR_TYPE_AND_CID};
 /// Deserialize a borrowed string with zero copies.
 ///
 /// ```
-/// # use serde_cbor::de;
+/// # use serde_ipld_dagcbor::de;
 /// let v: Vec<u8> = vec![0x66, 0x66, 0x6f, 0x6f, 0x62, 0x61, 0x72];
 /// let value: &str = de::from_slice(&v[..]).unwrap();
 /// assert_eq!(value, "foobar");
@@ -102,7 +102,7 @@ where
 /// Deserialize a `String`
 ///
 /// ```
-/// # use serde_cbor::de;
+/// # use serde_ipld_dagcbor::de;
 /// let v: Vec<u8> = vec![0x66, 0x66, 0x6f, 0x6f, 0x62, 0x61, 0x72];
 /// let value: String = de::from_reader(&v[..]).unwrap();
 /// assert_eq!(value, "foobar");
@@ -111,7 +111,7 @@ where
 /// Note that `from_reader` cannot borrow data:
 ///
 /// ```compile_fail
-/// # use serde_cbor::de;
+/// # use serde_ipld_dagcbor::de;
 /// let v: Vec<u8> = vec![0x66, 0x66, 0x6f, 0x6f, 0x62, 0x61, 0x72];
 /// let value: &str = de::from_reader(&v[..]).unwrap();
 /// assert_eq!(value, "foobar");
@@ -184,7 +184,7 @@ impl<'de, R> Deserializer<R>
 where
     R: Read<'de>,
 {
-    /// Constructs a `Deserializer` from one of the possible serde_cbor input sources.
+    /// Constructs a `Deserializer` from one of the possible serde_ipld_dagcbor input sources.
     ///
     /// `from_slice` and `from_reader` should normally be used instead of this method.
     pub fn new(read: R) -> Self {
@@ -210,13 +210,13 @@ where
         self
     }
 
-    /// Don't accept the new enum format used by `serde_cbor` versions >= v0.10.
+    /// Don't accept the new enum format used by `serde_ipld_dagcbor` versions >= v0.10.
     pub fn disable_standard_enums(mut self) -> Self {
         self.accept_standard_enums = false;
         self
     }
 
-    /// Don't accept the old enum format used by `serde_cbor` versions <= v0.9.
+    /// Don't accept the old enum format used by `serde_ipld_dagcbor` versions <= v0.9.
     pub fn disable_legacy_enums(mut self) -> Self {
         self.accept_legacy_enums = false;
         self
@@ -331,7 +331,8 @@ where
         }
     }
 
-    fn convert_str<'a>(buf: &'a [u8], buf_end_offset: u64) -> Result<&'a str> {
+    fn convert_str(buf: &[u8], buf_end_offset: u64) -> Result<&str> {
+        #[cfg(not(feature = "_do_not_use_its_unsafe_and_invalid_cbor"))]
         match str::from_utf8(buf) {
             Ok(s) => Ok(s),
             Err(e) => {
@@ -340,6 +341,10 @@ where
                 Err(Error::syntax(ErrorCode::InvalidUtf8, offset))
             }
         }
+
+        // Don't use this. This can lead to random panics and invalid CBOR.
+        #[cfg(feature = "_do_not_use_its_unsafe_and_invalid_cbor")]
+        Ok(unsafe { str::from_utf8_unchecked(buf) })
     }
 
     fn parse_str<V>(&mut self, len: usize, visitor: V) -> Result<V::Value>
@@ -552,11 +557,11 @@ where
     }
 
     fn parse_f32(&mut self) -> Result<f32> {
-        self.parse_u32().map(|i| f32::from_bits(i))
+        self.parse_u32().map(f32::from_bits)
     }
 
     fn parse_f64(&mut self) -> Result<f64> {
-        self.parse_u64().map(|i| f64::from_bits(i))
+        self.parse_u64().map(f64::from_bits)
     }
 
     fn parse_cid<V>(&mut self, visitor: V) -> Result<V::Value>
@@ -1212,8 +1217,8 @@ where
 /// `Deserializer::into_iter` method.
 ///
 /// ```
-/// # extern crate serde_cbor;
-/// use serde_cbor::de::Deserializer;
+/// # extern crate serde_ipld_dagcbor;
+/// use serde_ipld_dagcbor::de::Deserializer;
 /// use libipld_core::ipld::Ipld;
 ///
 /// # fn main() {
@@ -1244,7 +1249,7 @@ where
     T: de::Deserialize<'de>,
 {
     /// Create a new CBOR stream deserializer from one of the possible
-    /// serde_cbor input sources.
+    /// serde_ipld_dagcbor input sources.
     ///
     /// Typically it is more convenient to use one of these methods instead:
     ///
@@ -1374,7 +1379,7 @@ where
         // Match on the major type, it must be a byte string (major type 2)
         let len = match self.0.parse_u8()? {
             // CIDs always have a `0x00` prefix, hence they cannot be zero sized.
-            0x40 => Err(self.0.error(ErrorCode::LengthOutOfRange))?,
+            0x40 => return Err(self.0.error(ErrorCode::LengthOutOfRange)),
             byte @ 0x41..=0x57 => usize::try_from(byte - 0x40)
                 .map_err(|_| self.0.error(ErrorCode::LengthOutOfRange))?,
             0x58 => {
@@ -1393,7 +1398,7 @@ where
                 let len = self.0.parse_u64()?;
                 usize::try_from(len).map_err(|_| self.0.error(ErrorCode::LengthOutOfRange))?
             }
-            _ => Err(self.0.error(ErrorCode::UnexpectedCode))?,
+            _ => return Err(self.0.error(ErrorCode::UnexpectedCode)),
         };
 
         match self.0.read.read(len)? {
@@ -1412,10 +1417,10 @@ where
         if name == CID_SERDE_PRIVATE_IDENTIFIER {
             self.deserialize_bytes(visitor)
         } else {
-            Err(Error::message(format!(
+            return Err(Error::message(format!(
                 "This deserializer must not be called on newtype structs other than one named `{}`",
                 CID_SERDE_PRIVATE_IDENTIFIER
-            )))?
+            )));
         }
     }
 
